@@ -16,6 +16,7 @@
 #include <pthread.h>
 #include <errno.h>
 #include	"dsgwd_pi.h"
+#include	"dprs.h"
 #include	"crc.h"
 
 void    GPGLL (char string[]);
@@ -39,17 +40,11 @@ unsigned char	RadioSpeed[3];
 unsigned char	RadioDirection[3];
 unsigned char	Radio_GPS_A_MSG[120];
 unsigned char	Inet_GPS_A_MSG[120];
-unsigned char	Radio_GPS_A_Msg_send;
 unsigned char	Inet_GPS_A_Msg_send;
 unsigned char	DprsOpen = 0;
 unsigned int	AprsInetTimer = 0;
-unsigned int	AprsRadioTimer = 0;
-unsigned int	DprsBeaconTimer = 0;
-unsigned char	DprsMsgDstCallSign[10];
-unsigned char	DprsMsgSrcCallSign[10];
 unsigned char	AprsCallTBLCnt;
 unsigned char	ReqLoadAprsCallCheck;
-unsigned char	DprsMsgDstCallSignSave[9];
 
 char	RadioDprsSend, InetDprsSend;
 	
@@ -89,7 +84,6 @@ int	gps_sumcheck(char string[])
 {
 	unsigned char	*pnt;
 	unsigned char	sum, csum, tmp;
-
 	if (!memcmp (string, "$$CRC", 5))
 	{
 		return GPS_A_SumCheck(string);
@@ -349,7 +343,7 @@ unsigned int	update_crc_dstar( unsigned int  crc, unsigned char c )
     tmp = (crc & 0x00ff) ^ short_c;
     crc = (crc >> 8)  ^ crc_tabccitt[tmp];
 
-    return crc;
+    return crc & 0xffff;
 
 }  /* update_crc_dstar */
 
@@ -367,7 +361,7 @@ unsigned int	result_crc_dstar(unsigned int crc)
       tmp = crc;
       crc = (crc << 8) | (tmp >> 8 & 0xff);
 
-    return crc;
+    return crc & 0xffff;
 
 }  /* result_crc_dstar */
 
@@ -375,8 +369,7 @@ int	GPS_A_SumCheck(char string[])
 {
 	unsigned int	crc_dstar_ffff, k, k0, k1, k2, k3;
 	char	*pnt;
-	
-    crc_dstar_ffff = 0xffff;	/* nornal value 0xffff */
+    	crc_dstar_ffff = 0xffff;	/* nornal value 0xffff */
 	pnt = string + 10;
 
 	while (*pnt != 0x0a)
@@ -397,8 +390,7 @@ int	GPS_A_SumCheck(char string[])
 	if (k3 > 16) k3 -= 7;
 	k1 += k0 * 16;
 	k3 += k2 * 16;
-    k = k1 | (k3 << 8);
-
+    	k = k1 | (k3 << 8);
 	if (k == crc_dstar_ffff) return TRUE;
 	return	FALSE;
 }
