@@ -25,20 +25,20 @@
 	2014.02.16 V00.19 Bug fixed for CallCheck
 	2014.02.17 V00.20 Added DPRS Switch & DPRS STRIP
 		   V00.21 Added SO_REUSEADDR for each socket
+	2014.02.18 V00.22 Added DPRS
+	2014.02.20 V00.23 Fixed bug of DPRS
 */
 
 #include	"dsgwd_pi.h"
 #include	"version.h"
 #include	"node.h"
 #include	"holeP.h"	/* Hole Punching packet format */
+#include	"dprs.h"
 
 void	*node_adapter (void *arg);
 void	send_dsvt(void);
 void	receive_dsvt(void);
 
-int	dstSocket;
-int	udpSocket;
-
 struct	sockaddr_in	udpAddr;
 struct	sockaddr_in	sndAddr;
 
@@ -86,6 +86,11 @@ void CloseSocket()
                 close(dstSocket);
                 dstSocket=0;
         }
+	if (dprsSocket != 0){ 
+		close(dprsSocket);
+		dprsSocket = 0;
+	}
+
 	mq_close (rf_qid);
 	mq_close (inet_qid);
 	mq_unlink ("/dstar_rf");
@@ -292,7 +297,6 @@ int main(int argc, const char **argv)
         struct  timeval timeout;
 
 	// IP アドレス，ソケット，sockaddr_in 構造体
-	struct sockaddr_in dstAddr;
  	struct	hostent *hp;
 
   	char	buf[128];
@@ -347,8 +351,8 @@ int main(int argc, const char **argv)
 	NodeVendorID =  VendorID;
 	NodeProductID = ProductID;
 	CallCheck = FALSE;
-	DprsSW = FALSE;
-	DprsStrip = FALSE;
+	DPRS.DprsSW = FALSE;
+	DPRS.DprsStrip = FALSE;
 	DprsStripSW = FALSE;
 
 	config (argc, (char **)argv);
@@ -437,6 +441,33 @@ int main(int argc, const char **argv)
                 exit(-1);
         }
 
+	if (DPRS.DprsSW)
+	{
+        	dprsSocket = socket(PF_INET, SOCK_STREAM, 0);
+	        opt = 1;
+        	if (setsockopt(dprsSocket, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int)) != 0){
+                	logfile = fopen (LOGFILE, "a");
+                	now = time(NULL);
+                	fprintf (logfile, "%24.24s SO_REUSEADDR(dprsSocket) ERROR\n", ctime(&now));
+                	fclose (logfile);
+                	exit(-1);
+        	}
+        	bzero((char *)&dprsAddr, sizeof(dprsAddr));
+        	dprsAddr.sin_family = PF_INET;
+        	dprsAddr.sin_port = DPRS.Port;
+                hp = gethostbyname(DPRS.AprsServerDomainName);
+                memcpy (&dprsAddr.sin_addr, hp->h_addr_list[0], hp->h_length);
+        	if (connect(dprsSocket, (struct sockaddr *)&dprsAddr,
+                        sizeof(dprsAddr)) < 0){
+                	logfile = fopen (LOGFILE, "a");
+                	now = time(NULL);
+                	fprintf(logfile, "%24.24s Does not connect to '%s'.\n",
+                        ctime(&now),DPRS.AprsServerDomainName);
+                	fclose (logfile);
+                	CloseSocket();
+        	}
+	}
+
 	//接続
 	if (connect(dstSocket, (struct sockaddr *)&dstAddr, 
 			sizeof(dstAddr)) < 0){
@@ -509,6 +540,11 @@ int main(int argc, const char **argv)
 	if (width < rf_qid) width = rf_qid;
 	if (width < udpSocket) width = udpSocket;
 	if (width < cmdin) width = cmdin;
+	if (DPRS.DprsSW)
+	{
+		FD_SET(dprsSocket, &Mask);
+		if (width < dprsSocket) width = dprsSocket;
+	} 
 	width++;
 
 	while (1){
@@ -559,6 +595,21 @@ int main(int argc, const char **argv)
                                         send (dstSocket, (char *)&reqConMsg, 4, 0);
 					KeepAliveCnt = 0;
 				}
+
+
+				if (DPRS.Interval != 0)
+				{
+					if (DPRS.ClientID && ((time(NULL) - DprsBeaconTimer) >= (DPRS.Interval * 60))) DprsBeacon_Send();
+				}
+
+				if (!Msg.connectSW && !Msg.notfoundSW)			/* check the still voice message sending? */
+				{
+					//if (!PTT_On && !COS_On) DprsSMTP();
+					//if (AprsMessageSend) AprsMsgSend();
+					if (RadioDprsSend) RadioDprs_Send();
+					if (Radio_GPS_A_Msg_send) Radio_GPS_A_Send();
+				}
+	
 				break;
 			default:
                                 if (FD_ISSET(udpSocket, &readOk))
@@ -637,6 +688,13 @@ int main(int argc, const char **argv)
 				{
 					send_dsvt();
 				}
+				if (DPRS.DprsSW)
+				{
+					if (FD_ISSET(dprsSocket, &readOk))
+					{
+						dprs();
+					}
+				}
 				if (FD_ISSET(cmdin, &readOk))
 				{
                 			read (cmdin, buf, 64);
